LogFit Daemon
=============

|Codeship Status for albertyw/logfit-daemon|

The LogFit daemon watches log files and sends data to the LogFit app
for analysis.

Installation
------------

TODO

Usage
-----

.. code:: bash

    # Start in foreground mode
    python3 logfit/client.py [run|foreground]

    # Start in daemon mode
    python3 logfit/client.py start

    # Stop daemon
    python3 logfit/client.py stop

    # Restart the daemon
    python3 logfit/client.py restart

    # Get the daemon status
    python3 logfit/client.py status


Development
-----------

.. code:: bash

    pip install -r requirements-test.txt
    coverage run setup.py test
    coverage report
    flake8


Publishing
----------

.. code:: bash

    pip install twine
    python setup.py sdist bdist_wheel
    twine upload dist/*

.. |Codeship Status for albertyw/logfit-daemon| image:: https://app.codeship.com/projects/30a05060-4276-0135-97f1-6255c2e8e3ba/status?branch=master
   :target: https://app.codeship.com/projects/230349
